#define MOZ_SOURCE_STAMP d2ab9c39bd1059d74acb3d9ac87dbfbba913427b
#define MOZ_SOURCE_REPO https://hg.mozilla.org/releases/mozilla-beta
#define MOZ_SOURCE_URL https://hg.mozilla.org/releases/mozilla-beta/rev/d2ab9c39bd1059d74acb3d9ac87dbfbba913427b
